@@ -60,6 +60,9 @@ static NPNetscapeFuncs browserFunctions;
 
 static gint send_message_to_appletviewer (gchar const* value);
 static gint receive_message_from_appletviewer (gchar* string);
+static gboolean callbackViewerRead (GIOChannel* source,
+				    GIOCondition condition,
+				    gpointer data);
 
 struct GCJPluginData
 {
@@ -80,6 +83,8 @@ static GIOChannel *input_from_appletviewer = NULL;
 
 static int instance_counter = 0;
 
+static guint viewer_watch = 0;
+
 static void gcjplugindata_new (GCJPluginData ** data);
 static void gcjplugindata_destroy (GCJPluginData ** data);
 
@@ -543,6 +548,10 @@ NP_Initialize(NPNetscapeFuncs* browserTable, NPPluginFuncs* pluginTable)
 
   g_printerr ("Got confirmation that gcjappletviewer is running.\n");
 
+  // Add callback to input channel from appletviewer.
+  viewer_watch = g_io_add_watch (input_from_appletviewer, G_IO_IN,
+				 callbackViewerRead, NULL);
+  
   return NPERR_NO_ERROR;
 }
 
@@ -643,3 +652,21 @@ NP_Shutdown(void)
 
   return NPERR_NO_ERROR;
 }
+
+static gboolean
+callbackViewerRead (GIOChannel *source, GIOCondition condition, gpointer data)
+{
+  // Read pipe data.
+  GError *err = NULL;
+  gchar* read_buf;
+  if (g_io_channel_read_line (input_from_appletviewer,
+                              &read_buf, NULL, NULL, &err)
+      != G_IO_STATUS_NORMAL)
+    {
+      g_printerr ("receive_message_from_appletviewer: Error: %s\n", err->message);
+    }
+
+  // FIXME: Add handling of read input here.
+
+  return TRUE;
+}
