@@ -32,15 +32,46 @@ import java.io.OutputStream;
 import java.net.URL;
 import java.util.ArrayList;
 import java.util.Arrays;
+import java.util.HashMap;
 import java.util.Iterator;
+import java.util.MissingResourceException;
 import java.util.LinkedList;
 import java.util.List;
+import java.util.ResourceBundle;
 import java.util.Vector;
 
 
 class AppletViewer
 {
-  static native String getenv(String name);
+  /**
+   * The localized strings are kept in a separate file
+   */
+  public static ResourceBundle messages = ResourceBundle.getBundle
+    ("gnu.gcjwebplugin.locale.MessagesBundle");
+
+  private static HashMap classLoaderCache = new HashMap();
+  
+  private static ClassLoader getClassLoader(URL codebase, ArrayList archives)
+  {
+    // Ask cache for existing class loader.
+    AppletClassLoader loader = (AppletClassLoader) classLoaderCache.get(codebase);
+
+    if (loader == null)
+      {
+	// FIXME: why does URLClassLoader throw a NoClassDefFoundError
+	// when the html file we pass it is in the current working
+	// directory?  (e.g. the Slime Volleyball applet).  I suspect
+	// a URLClassLoader bug in libgcj.
+
+	// XXX: Add archives only the first time we see a codebase ...
+	loader = new AppletClassLoader(codebase, archives);
+
+	// Add new class loader to cache.
+	classLoaderCache.put(codebase, loader);
+      }
+    
+    return loader;
+  }
 
   static Applet createApplet(AppletTag tag)
   {
@@ -48,19 +79,8 @@ class AppletViewer
 
     try
       {
-        AppletClassLoader loader;
-
-	// FIXME: why does URLClassLoader throw a NoClassDefFoundError
-	// when the html file we pass it is in the current working
-	// directory?  (e.g. the Slime Volleyball applet).  I suspect
-	// a URLClassLoader bug in libgcj.
-	if (tag.archives.size() == 0)
-	  loader = new AppletClassLoader
-	    (new URL [] { tag.prependCodebase ("") });
-	else
-	  loader = new AppletClassLoader
-	    ((URL []) tag.archives.toArray (new URL [tag.archives.size()]));
-
+        ClassLoader loader = getClassLoader(tag.prependCodebase (""),
+						  tag.archives);
 	String code = tag.code;
 
 	if (code.endsWith(".class"))
@@ -86,20 +106,17 @@ class AppletViewer
 
   static void printHelpMessage(int status)
   {
-    System.out.println("Usage: gcjappletviewer [options] <filename>.class | <filename>.html... | url...");
-    System.out.println("Options:");
-    System.out.println("  --help                            Display this message and exit");
-    System.out.println("  --version                         Print version information and exit");
-    System.out.println("  --code=<classname>[.class]        Run applet by class name or file name");
-    System.out.println("  --codebase=<directory>            Set applet codebase");
-    System.out.println("  --archive=<filename>.jar[,...]    Add archives to applet class loader");
-    System.out.println("  --param=<name>,<value>            Pass parameter to applet");
-    System.out.println("  --width=<width>                   Set width of applet viewer frame");
-    System.out.println("  --height=<height>                 Set height of applet viewer frame");
-    System.out.println("  --plugin=<in pipe>,<out pipe>     Enable plugin mode");
-    System.out.println("  -debug                            For appletviewer compatibility");
-    System.out.println("  -encoding <encoding>              Specify character encoding used by HTML files");
-    System.out.println("  -J<runtime flag>                  Pass argument to the Java runtime");
+    try
+      {
+	for (int count = 0; ; count++)
+	  System.out.println
+	    (AppletViewer.messages.getString("gcjwebplugin.help." + count));
+      }
+    catch (MissingResourceException e)
+      {
+	// Do nothing here.
+      }
+    
     System.exit(status);
   }
 
@@ -116,7 +133,8 @@ class AppletViewer
 
     if (args.length == 0)
       {
-	System.err.println("gcjappletviewer: no input files");
+	System.err.println(AppletViewer.messages.getString
+			   ("gcjwebplugin.no_input_files"));
 	printHelpMessage(1);
       }
 
@@ -282,9 +300,7 @@ class AppletViewer
     if (dimensions.width < 0)
       dimensions.width = (int) (1.6 * dimensions.height);
 
-    System.err.println(dimensions);
-
-    System.setSecurityManager(new AppletSecurityManager());
+    System.setSecurityManager(new AppletSecurityManager(pluginMode));
     
     if (pluginMode)
       {
