@@ -85,7 +85,7 @@ public class ConsoleDialog extends Frame
    */
   public ConsoleDialog()
   {
-    super("gcjwebplugin java console");
+    super(AppletViewer.messages.getString("gcjwebplugin.console_title"));
 
     setSize(400, 200);
     setLayout(new BorderLayout());
@@ -105,11 +105,11 @@ public class ConsoleDialog extends Frame
     panel.setLayout(new FlowLayout());
     add(panel, BorderLayout.SOUTH);
 
-    buttonClear = new Button("Clear");
+    buttonClear = new Button(AppletViewer.messages.getString("gcjwebplugin.console_clear"));
     buttonClear.addActionListener(this);
     panel.add(buttonClear);
 
-    buttonHide = new Button("Hide");
+    buttonHide = new Button(AppletViewer.messages.getString("gcjwebplugin.console_hide"));
     buttonHide.addActionListener(this);
     panel.add(buttonHide);
 
