@@ -57,10 +57,9 @@ class PluginAppletViewer
     consoleDialog = new ConsoleDialog();
 
     stdOut = System.out;
-    System.out = consoleDialog.getPrintStream();
-
+    System.setOut(consoleDialog.getPrintStream());
     stdErr = System.err;
-    System.err = consoleDialog.getPrintStream();
+    System.setErr(consoleDialog.getPrintStream());
   }
 
   static void start(InputStream inputStream, OutputStream outputStream)
@@ -130,9 +129,15 @@ class PluginAppletViewer
       }
   }
 
+  /**
+   * Write string to plugin.
+   * 
+   * @param message the message to write
+   *
+   * @exception IOException if an error occurs
+   */
   static void write(String message) throws IOException
   {
-    // Write string to plugin.
     pluginOutputStream.write(message, 0, message.length());
     pluginOutputStream.newLine();
     pluginOutputStream.flush();
@@ -140,9 +145,15 @@ class PluginAppletViewer
     stdOut.println("  PIPE: applet viewer wrote: " + message);
   }
 
+  /**
+   * Read string from plugin.
+   *
+   * @return the read string
+   *
+   * @exception IOException if an error occurs
+   */
   static String read() throws IOException
   {
-    // Read string from plugin.
     String message = pluginInputStream.readLine();
 
     stdOut.println("  PIPE: applet viewer read: " + message);
