@@ -37,7 +37,7 @@ import java.util.HashMap;
 
 class PluginAppletWindow extends EmbeddedWindow
 {
-  private static int test_window_count;
+  private static int testWindowCount;
   private static HashMap contexts = new HashMap();
   private Applet applet;
   private AppletTag tag;
@@ -86,9 +86,9 @@ class PluginAppletWindow extends EmbeddedWindow
     ((PluginAppletContext) context).addApplet(applet);
     applet.setStub(new CommonAppletStub(tag, context));
 
-    String test_window_count = AppletViewer.getenv("GCJAPPLETVIEWER_NOGUI");
+    String testWindowCount = System.getProperty("gnu.gcjwebplugin.test.windowCount");
 
-    if (test_window_count == null)
+    if (testWindowCount == null)
       {
 	setVisible(true);
 
@@ -101,7 +101,7 @@ class PluginAppletWindow extends EmbeddedWindow
 	applet.init();
 	applet.start();
 
-	if (++this.test_window_count == Integer.decode(test_window_count)
+	if (++this.testWindowCount == Integer.decode(testWindowCount)
 	                                       .intValue())
 	  System.exit(0);
       }
