@@ -39,7 +39,7 @@ import java.util.List;
 
 class StandaloneAppletWindow extends Frame
 {
-  private static int test_window_count;
+  private static int testWindowCount;
   private static HashMap contexts = new HashMap();
   Applet applet;
   Label status = new Label();
@@ -103,8 +103,9 @@ class StandaloneAppletWindow extends Frame
 
     setTitle("GCJ Applet Viewer: " + tag.code);
 
-    String test_window_count = AppletViewer.getenv("GCJAPPLETVIEWER_NOGUI");
-    if (test_window_count == null)
+    String testWindowCount = System.getProperty("gnu.gcjwebplugin.test.windowCount");
+
+    if (testWindowCount == null)
       {
 	// Create the frame's peer.  Otherwise getPreferredSize will read
 	// its insets as 0.
@@ -122,7 +123,7 @@ class StandaloneAppletWindow extends Frame
 	applet.init();
 	applet.start();
 
-	if (++this.test_window_count == Integer.decode(test_window_count)
+	if (++this.testWindowCount == Integer.decode(testWindowCount)
 	                                       .intValue())
 	  System.exit(0);
       }
